Polski Związek Działkowców - Strona główna
Author: Esencja Studio @ www.esencja-studio.pl
Description: Polski Związek Działkowców

Rodzina
Zdrowie
Ekologia
Edukacja
Wypoczynek

## Nowy regulamin ROD - 30.10.2015

W dniu 1 października br. Krajowa Rada Polskiego Związku Działkowców uchwaliła nowy regulamin ROD, który wejdzie w życie 1 stycznia 2016 r. To kolejny etap dostosowywania reguł obowiązujących w 4738 ogrodach prowadzonych przez PZD do nowej ustawy o rodzinnych ogrodach działkowych. Zgodnie z ustawą, zawarte w nim zasady mają obowiązywać nie tylko działkowców, ale każdą osobę przebywającą w ogrodzie.

czytaj więcej

### działkowiec

### Zielona Rzeczpospolita

### Informator Działkowca

### Biuletyn Informacyjny

### Mój Ogródek

### Bieżące wydarzenia

### Działkowcy walczą o swoje prawa

## Czas na podsumowanie i rozliczenie dotacji w ROD - 03.12.2015

Tarnobrzeski Samorząd wpiera dotacją celową nasze ogrody już od 2009 roku. W roku 2015 kwota przyznanej dotacji to prawie 70 000zł na 7 ogrodów w obrębie Miasta Tarnobrzega.

czytaj więcej

## Przegląd medialnych doniesień o działkowcach i ogrodach działkowych - 03.12.2015

W najnowszym przeglądzie prasy przeczytasz m.in. o wzmożonej aktywności złodziei, którzy plądrują altany w ogrodach działkowych. Dowiesz się, co można zrobić, gdy nie jesteśmy w stanie porozumieć się z sąsiadem, kiedy jego drzewo utrudnia swobodne korzystanie z własnej działki, a ponadto przeczytasz o spotkaniu burmistrza Wągrowca z działkowcami, problemie pruszkowskich działkowców z łamiącymi się konarami oraz o coraz większej popularności ogrodów działkowych wśród młodych.

czytaj więcej

## Poznańskie ogrody otwierają się na seniorów - 03.12.2015

Poznańscy działkowcy chcą otwierać się na potrzeby seniorów w wieku 60+ nie tylko z własnego środowiska, ale także z lokalnej społeczności. Dysponując bazą lokalową w wielu ogrodach działkowych organizowane są wczasy na działkach, funkcjonują kluby i koła zainteresowań. Przed działkowcami pojawia się jednak kolejna szansa i wyzwanie. Przyjęty przez Radę Ministrów wieloletni program "Senior - WIGOR" jest szansą dla ogrodów działkowych nie tylko na rozszerzenie swojej działalności ukierunkowanej na otwieranie sie na potrzeby społeczeństwa, ale także szansą na unowocześnienie posiadanej infrastruktury ROD przez pozyskanie środków z programu.

czytaj więcej

## Szkolenie Przewodniczących Ogrodowych Komisji Rewizyjnych PZD w okręgu warmińsko - mazurskim - 03.12.2015

W dniu 1 grudnia 2015 r. w Olsztynie odbyło się szkolenie Przewodniczących Ogrodowych Komisji Rewizyjnych Polskiego Związku Działkowców okręgu warmińsko-mazurskiego.

czytaj więcej

## Dziennik Trybuna: Zimowi lokatorzy - problem rodzinnych ogrodów działkowych - 02.12.2015

"Od wczesnej wiosny do późnej jesieni działkowcy spędzają czas w rodzinnych ogrodach działkowych na uprawie roślin i wypoczynku. Na zimę ogrody jednak pustoszeją, a działki okrywają się grubą warstwą śnieżnego puchu. Niestety ROD tylko z pozoru są puste w okresie zimowym, bowiem altanki stają się schronieniem dla osób bezdomnych i niektórych działkowców, którzy swoje altany chcieliby traktować jak całoroczne domy" - czytamy w Dzienniku Trybuna.

czytaj więcej

## Spotkanie z Marszałkiem Województwa Warmińsko-Mazurskiego w sprawie środków unijnych - 02.12.2015

W dniu 30 listopada 2015 r. w Urzędzie Marszałkowskim w Olsztynie odbyło się spotkanie Marszałka Województwa Warmińsko-Mazurskiego Pana Gustawa Marka Brzezina z przedstawicielami OZ Warmińsko-Mazurskiego i OZ Elbląskiego. Z ramienia OZ PZD Warmińsko-Mazurskiego w spotkaniu udział wzięli: Prezes OZ PZD Pan Zbigniew Kołodziejczak. Okręg Elbląski reprezentowali: Prezes OZ PZD - Pan Antoni Dalak oraz I Wiceprezes OZ PZD - Pan Zygmunt Wójcik.

czytaj więcej

## OZ w Częstochowie zakończył szkolenia dla nowych działkowców - 02.12.2015

Okręgowy Zarząd Polskiego Związku Działkowców w Częstochowie w roku 2015 zorganizował zgodnie z przyjętym planem pracy na 2015 rok 11 kursów dla nowych użytkowników działek w rodzinnych ogrodach działkowych. Szkolenia odbywały się od stycznia do listopada w Ośrodku szkolenia przy Okręgowym Zarządzie oraz w Lublińcu i Blachowni. W sumie w tegorocznych szkoleniach wzięło udział 360 nowych użytkowników, którzy gospodarują na 268 działkach w naszych rodzinnych ogrodach działkowych.

czytaj więcej

## III posiedzenie Okręgowego Zarządu Mazowieckiego PZD - 02.12.2015

30 listopada br. w ośrodku szkoleniowym OZM PZD w Warszawie odbyło się posiedzenie Okręgowego Zarządu Mazowieckiego PZD, któremu przewodniczył Prezes OZM PZD Zygmunt Kacprzak. W obradach uczestniczył Prezes PZD Eugeniusz Kondracki, a także Wiceprezes PZD Stanisław Zawadka, Monika Pilzak z Wydziału Gospodarki Gruntami KR PZD i Kierownik Wydziału Prezydialnego KR Marek Pytka.

czytaj więcej

## Kierunki zmian w Gdańsku? Nic o Nas bez Nas - 02.12.2015

30 listopada 2015 r. w siedzibie Biura Rozwoju Miasta Gdańska odbyło się robocze spotkanie poświęcone tematyce ogrodów działkowych, ich rozwojowi w mieście, możliwościach dalszego działania, problemów ogrodów oraz przygotowywanego nowego studium kierunków zagospodarowania przestrzennego. W spotkaniu uczestniczył starszy inspektor ds. terenowo-prawnych Okręgowego Zarządu PZD w Gdańsku Artur Lemański.

czytaj więcej

## Działkowcy u Prezydenta Gdyni - 02.12.2015

Po raz kolejny doszło do spotkania przedstawicieli Kolegium Prezesów Gdyńskich Ogrodów Działkowych z Prezydentem Miasta Gdynia Panem Wojciechem Szczurkiem. Spotkanie przebiegało w miłej i życzliwej atmosferze. Poruszono wiele tematów, które nurtowały do tej pory użytkowników działek. Wiele przedstawianych tematów znalazło uznanie w oczach Prezydenta Miasta. Uzgodniono, nowe dotychczas niestosowane formy współpracy. Działkowcy, w co raz w szerszym stopniu będą się otwierać na potrzeby społeczności lokalnych, przedszkoli oraz szkół.

czytaj więcej

## Rodzinne ogrody działkowe – przegląd mediów - 01.12.2015

Media donoszą o kolejnych kontrolach służb miejskich w ROD pod kątem przerywania w nich osób bezdomnych. Jednocześnie proszą o zgłaszanie na numery alarmowe ich obecności w ogrodach. Ponadto w najnowszym przeglądzie prasy: działkowcy z ROD "Górki Ustanowskie " w Szczecinie świętują - ich ogród nie zostanie zlikwidowany przez władze miasta, a także kłopoty głubczyckich działkowców, których 10 ha ROD władze Głubczyc chcą przejąć pod inwestycje. Zachęcamy do lektury!

czytaj więcej

## IV posiedzenie OZ we Wrocławiu - 01.12.2015

W dniu 28 listopada 2015r. odbyło się IV-te posiedzenie Okręgowego Zarządu PZD we Wrocławiu. Posiedzenie dotyczyło tak ważnych tematów jak: budownictwa ponadnormatywnego na działkach w ROD, zamieszkiwania na działkach w ROD, wprowadzenia terenów ogrodów do Studium uwarunkowań i kierunków zagospodarowania przestrzennego Wrocławia, pozyskiwania środków unijnych i Wojewódzkiego funduszu Ochrony Środowiska i Gospodarki Wodnej na zadania w ogrodach, zebrań sprawozdawczych w ROD okręgu wrocławskiego w 2016 r.

czytaj więcej

Sprawdź wszystkie wydarzenia

## Regulamin ROD - 02.12.2015

1 października 2015 roku Krajowa Rada PZD uchwaliła regulamin ROD. Nowy regulamin ROD wchodzi w życie 1 stycznia 2016 roku. W załączeniu dostępny jest obecnie obowiązujący regulamin ROD oraz nowy regulamin ROD, który wejdzie w życie od 1 stycznia 2016 roku.

czytaj więcej

## Statut PZD - 02.12.2015

9 września 2015r. w Krajowym Rejestrze Sądowym (KRS) zarejestrowany został statut PZD uchwalony 2 lipca br. przez XII Krajowy Zjazd Delegatów PZD (STATUT dostępny tutaj) Tym samym spełniono obowiązek wynikający z art. 68 ustawy o ROD, a więc uchwalono - w terminie 18 miesięcy od dnia wejścia w życie ustawy - nowy statut na zasadach określonych w dotychczasowym statucie, a także zarejestrowano go w KRS (zobacz dokument).

czytaj więcej

## Gdzie znaleźć informacje o funduszach unijnych? - 02.12.2015

Od 2004 r. w Polsce dofinansowanie z UE uzyskało około 200 tys. projektów. Na to, by dołączyć do tego grona i skorzystać ze środków europejskich nigdy nie jest za późno. Na stronie funduszeeuropejskie.gov.pl znajdziesz wszelkie potrzebne informacje, aby pozyskać fundusze także dla swojego ogrodu. Sprawdź też zakładkę aktualności - fundusze unijne na stronie pzd.pl.

czytaj więcej

## Komunikat KR PZD w sprawie wydania i dystrybucji Statutu PZD, Regulaminu ROD i innych dokumentów - 02.12.2015

Krajowa Rada PZD informuje, że Prezydium Krajowej Rady w ostatnim czasie podjęło kilka decyzji o wydaniu pozycji, które ułatwią funkcjonowanie i właściwe zarządzanie organom PZD, a działkowcom ułatwią korzystanie z prawa w PZD.

czytaj więcej

## Komunikat KR PZD w sprawie pomocy finansowej dla ROD - 02.12.2015

Polski Związek Działkowców w trzech kwartałach 2015 roku przekazał na rzecz 368 rodzinnych ogrodów działkowych środki finansowe w formie dotacji w wysokości blisko 2 miliony 700 tysięcy złotych. Środki przeznaczane są dla ROD, które podejmują się realizacji zadań inwestycyjnych związanych z budową nowej lub modernizacją istniejącej ogólnoogrodowej infrastruktury.

czytaj więcej

## Komunikat KR PZD: opłaty w ROD bez zmian - 02.12.2015

W dniu 25 listopada 2015 r. KR PZD podjęła decyzje finansowe odnoszące się do wszystkich ROD prowadzonych przez PZD. Jak wynika z przyjętych uchwał, w 2016 r. te z obciążeń finansowych działkowców, o których wysokości decyduje KR PZD, mają pozostać na tegorocznym poziomie.

czytaj więcej

## Komunikat KR PZD w sprawie regulacji stanu prawnego gruntów ROD - 01.12.2015

Krajowa Rada PZD na posiedzeniu w dniu 25 listopada 2015 r. zapoznała się ze stanem zaawansowania działań w zakresie regulacji stanu prawnego gruntów ROD na podstawie art. 76 ustawy o ROD. Temat jest na bieżąco monitorowany, gdyż regulacja stanu prawnego gruntów ROD jest niezwykle istotna dla dalszego ich funkcjonowania oraz zabezpieczenia praw działkowców i PZD. Dotychczas zakwalifikowano 1684 ROD o powierzchni bliskiej 10tyś ha do regulacji stanu prawnego na podstawie art. 76 ustawy o ROD.

czytaj więcej

## Komunikat KR PZD w sprawie pozyskiwania środków z budżetu gminy - 30.10.2015

KR PZD przypomina zarządom ROD o możliwości ubiegania się o dotacje celowe z budżetu Gmin. Obecne unormowania zawarte w art. 17 ustawy z dnia 13 grudnia 2013 r. o ROD, dają podstawy prawne gminom do udzielenia dotacji przeznaczonej na rozwój ROD, a w szczególności na budowę lub modernizację infrastruktury ogrodowej, o ile wpłynie to na poprawę warunków do korzystania z ROD przez działkowców lub zwiększy dostępność społeczności lokalnej do ROD. Zatem warto potrzebami ogrodów i działkowców zainteresować włodarzy gmin pamiętając, że gminy mają obowiązek do dnia 15 listopada każdego roku opracować projekt planu budżetu swojej gminy.

czytaj więcej

## Komunikat KR PZD w sprawie druków dokumentów dla ROD dotyczących inwestycji i remontów - 30.10.2015

Zbliża się okres walnych zebrań sprawozdawczo – wyborczych członków PZD w ROD. Jest to najlepsza okazja, aby zastanowić się nad potrzebami ROD w zakresie zagospodarowania i zaplanować nowe inwestycje lub remonty. Mimo, iż co roku ogrody działkowe przeprowadzają wiele inwestycji i remontów infrastruktury ogrodowej, to potrzeby w tym zakresie są w dalszym ciągu spore.

czytaj więcej

## XII Krajowy Zjazd Delegatów PZD - 30.10.2015

2 - 3 lipca w Warszawie odbył się XII Krajowy Zjazd Delegatów. Zjazd uchwalił statutu PZD, wybrał nowe władze Związku oraz podjął szereg uchwał i stanowisk. W załączeniu dokumenty zjazdowe.

czytaj więcej

## Posiedzenia KR PZD minionej kadencji - 30.10.2015

W załączeniu uchwały, stanowiska i listy podjęte przez Krajową Radę PZD w minionej kadencji.

czytaj więcej

Działkowcy w obronie Ustawy o ROD

### Galeria zdjęć

### Filmy

- XII Krajowy Zjazd Delegatów Polskiego Związku Działkowców

  Wystawa tczewskich ROD na Krajowych Dniach Działkowca 2015

- Podziękowania dla długoletnich Prezesów ROD

  Działkowcy składają 700 000 podpisów

- Nadzwyczajny XI Krajowy Zjazd Delegatów PZD

  Spotkanie Premier Ewy Kopacz z warszawskimi działkowcami

- Krajowe Dni Działkowca - Tczew 2015

  XII Krajowy Zjazd Delegatów - dzień drugi

- Działkowe wypieki oraz wina i nalewki

  Krajowe Dni Działkowca 2014r.

- Altany kiedyś

  Altany-kiedys-i-dzisiaj

- Wiosna na działkach

  Altany dziś cz. 2

- Altany dziś

  Altany w holenderskich ogrodach działkowych

- Altany dziś cz.3

  Ogólnopolska Manifestacja Działkowców (1)

- Manifestacja Działkowców (10 października)

  Manifestacja działkowców (10.10.13)

- Ogólnopolska Manifestacja Działkowców (galeria2)

  Ogólnopolska manifestacja działkowców (10.10)

- Manifestacje działkowców 20 września 2013

  Krajowe Dni Działkowca 2013 - kosze dożynkowe

- Manifestacja działkowców przed kancelarią premiera Donalda Tuska

  Krajowe Dni Działkowca 2013

- Manifestacja działkowców

  Spotkanie z przedstawicielami PSL

- PZD i Greenpeace pomagają pszczołom

  Pikiety działkowców pod biurami poselskimi PO

- Działkowcy popierają projekt obywatelski

  Spotkanie z Marszałek Sejmu

- Działkowcy składają podpisy w Sejmie

  Narada w Sieradzu

- Trybunał Konstytucyjny

  Nadzwyczajny X Krajowy Zjazd Delegatów PZD

- Nadzwyczajny X Krajowy Zjazd Delegatów PZD

  Pokazy cięcia w ROD

- Sadzenie drzewka kongresowego w Okręgu Świętokrzyskim

  I Kongres PZD

- IX Krajowy Zjazd Delegatów

  II Kongres PZD

- //www.youtube.com/embed/nDqRkM3Ds30
- http://www.youtube.com/embed/6KKJ5Ta4gC0
- http://www.youtube.com/embed/9I69JX9lyts
- http://www.youtube.com/embed/T4jZ5sFw7Dk
- http://www.youtube.com/embed/ZYCzrdty2oQ
- http://www.youtube.com/embed/ojYlTv0U_mo
- http://www.youtube.com/embed/kTzs0zG4rwE
- http://www.youtube.com/embed/WM-i1bY2bFc
- http://www.youtube.com/embed/kXZGLzyFpTI
- http://www.youtube.com/embed/Y_EoDMn_36E
- http://www.youtube.com/embed/AMDBhoL0F9k
- http://www.youtube.com/embed/IKuUEX8cZIA

Twoja działka
czeka na Ciebie

Copyright © 2015 Polski Związek Działkowców All rights reserved.

made by Esencja Studio